@@ -122,7 +122,7 @@ FAILEDOPERATION_NOPERMISSION = 'FailedOperation.NoPermission'
 # 操作不允许。
 FAILEDOPERATION_NOTALLOW = 'FailedOperation.NotAllow'
 
-# 请求正在处理中，请稍候再试。
+# 请求正在处理中，请稍后再试。
 FAILEDOPERATION_PROCESSING = 'FailedOperation.Processing'
 
 # 查询资源标签失败。
@@ -176,12 +176,18 @@ INTERNALERROR_NOPERMISSION = 'InternalError.NoPermission'
 # 操作不允许。
 INTERNALERROR_NOTALLOW = 'InternalError.NotAllow'
 
+# 查询标签失败。
+INTERNALERROR_QUERYBINDINGTAGSFAILED = 'InternalError.QueryBindingTagsFailed'
+
 # 获取HDFS存储信息失败。
 INTERNALERROR_QUERYHDFSINFOFAILED = 'InternalError.QueryHDFSInfoFailed'
 
 # 查询预付费资源组详情失败。
 INTERNALERROR_QUERYRESOURCEGROUPFAILED = 'InternalError.QueryResourceGroupFailed'
 
+# 查询子网信息失败。
+INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
+
 # 停止任务失败。
 INTERNALERROR_STOPJOBINSTANCEFAILED = 'InternalError.StopJobInstanceFailed'
 
@@ -242,6 +248,9 @@ INVALIDPARAMETERVALUE_DUPLICATENAME = 'InvalidParameterValue.DuplicateName'
 # 训练框架对应的版本不支持，请阅读文档查看TIONE目前支持的框架和版本。
 INVALIDPARAMETERVALUE_FRAMEWORKVERSIONNOTSUPPORT = 'InvalidParameterValue.FrameworkVersionNotSupport'
 
+# 训练任务镜像不存在。
+INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
+
 # 无效的过滤器。
 INVALIDPARAMETERVALUE_INVALIDFILTER = 'InvalidParameterValue.InvalidFilter'
 
@@ -299,7 +308,7 @@ RESOURCESSOLDOUT = 'ResourcesSoldOut'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
-# 资源不属于当前登陆用户主账号，无权限访问。
+# 资源不属于当前登录用户主账号，无权限访问。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
 # 未知参数错误。
